@@ -20,22 +20,20 @@
 
 #include "dolphinsettingsdialog.h"
 
-#include <dolphinmainwindow.h>
 #include "dolphin_generalsettings.h"
+#include "dolphinmainwindow.h"
 #include "general/generalsettingspage.h"
 #include "navigation/navigationsettingspage.h"
 #include "services/servicessettingspage.h"
 #include "startup/startupsettingspage.h"
-#include "viewmodes/viewsettingspage.h"
 #include "trash/trashsettingspage.h"
+#include "viewmodes/viewsettingspage.h"
 
 #include <KAuthorized>
-#include <KWindowConfig>
 #include <KLocalizedString>
-#include <QIcon>
+#include <KWindowConfig>
 
 #include <QPushButton>
-#include <QDialogButtonBox>
 
 DolphinSettingsDialog::DolphinSettingsDialog(const QUrl& url, QWidget* parent) :
     KPageDialog(parent),
