@@ -20,14 +20,14 @@
 
 #include "viewsettingspage.h"
 
-#include <views/dolphinview.h>
+#include "views/dolphinview.h"
 #include "viewsettingstab.h"
 
-#include <QVBoxLayout>
-#include <QTabWidget>
-
 #include <KLocalizedString>
 
+#include <QTabWidget>
+#include <QVBoxLayout>
+
 ViewSettingsPage::ViewSettingsPage(QWidget* parent) :
     SettingsPageBase(parent),
     m_tabs()
@@ -56,7 +56,7 @@ ViewSettingsPage::ViewSettingsPage(QWidget* parent) :
     m_tabs.append(compactTab);
     m_tabs.append(detailsTab);
 
-    topLayout->addWidget(tabWidget, 0, 0);
+    topLayout->addWidget(tabWidget, 0, nullptr);
 }
 
 ViewSettingsPage::~ViewSettingsPage()
